==> aom-docs-3.5.0-1-x86_64.pkg.tar.zst: usr/share/doc/aom/structmacroblock.js <==
var structmacroblock =
[
    [ "plane", "structmacroblock.html#a764c3f23fd2e1d581a1265bad933c196", null ],
    [ "e_mbd", "structmacroblock.html#a22c8a3380f06cf7061181e1ba5de5d5a", null ],
    [ "mbmi_ext", "structmacroblock.html#af9333e247364df6c3e316bf5ad221b56", null ],
    [ "mbmi_ext_frame", "structmacroblock.html#a045f36d0d8a27dcd8be792f5cdcdd3b0", null ],
    [ "row_ctx", "structmacroblock.html#a2a5f8b9affa29e2e6f02d438cff7389d", null ],
    [ "tile_pb_ctx", "structmacroblock.html#adbcb7d6e4e0fbe5180f62dd9d2d9d8a3", null ],
    [ "cb_coef_buff", "structmacroblock.html#aac7182bb34bf1ca7c57b5ca0acdf085f", null ],
    [ "cb_offset", "structmacroblock.html#ae1c34d0f490e6fde5878029e6446664e", null ],
    [ "obmc_buffer", "structmacroblock.html#a90eeb3bb2b16490acc010bff8cd69f4a", null ],
    [ "palette_buffer", "structmacroblock.html#a646112bcb60cf889bdfefc2c213086ec", null ],
    [ "comp_rd_buffer", "structmacroblock.html#a5616dd030329ca191ce1a31200459473", null ],
    [ "tmp_conv_dst", "structmacroblock.html#a37f1df249ef1e12f57b9bfa2786aa086", null ],
    [ "tmp_pred_bufs", "structmacroblock.html#a099a8be27fac5a66f655471c91eb2d93", null ],
    [ "qindex", "structmacroblock.html#aada35cc4d590ca2912c3305d49d1e460", null ],
    [ "delta_qindex", "structmacroblock.html#a00c8c8d03fa0236917ca3e6485f5f0c5", null ],
    [ "rdmult", "structmacroblock.html#a1bfbaf644bed64fcdc41119e2da0843f", null ],
    [ "intra_sb_rdmult_modifier", "structmacroblock.html#a54fe4d282d137868d98adc7ad7abb9dd", null ],
    [ "rb", "structmacroblock.html#a228e767c53ab8ab4d8bfe446d33de98e", null ],
    [ "mb_energy", "structmacroblock.html#a0de89964c4b6f0c74b9a74c494a8f6e4", null ],
    [ "sb_energy_level", "structmacroblock.html#a07e39b2368528999366be1ea379f50e0", null ],
    [ "mode_costs", "structmacroblock.html#a3c8ed6c74a25055e311a476b5ad4702c", null ],
    [ "mv_costs", "structmacroblock.html#abe2b85272a08056fb6332699d350fe98", null ],
    [ "dv_costs", "structmacroblock.html#a5c84d87000da6a479c483aceee12f346", null ],
    [ "coeff_costs", "structmacroblock.html#a165159d92c9f6d7c4ec1b8ad6c47f4f0", null ],
    [ "errorperbit", "structmacroblock.html#adb20ef0cebd61dc8a468f5b928f27a10", null ],
    [ "sadperbit", "structmacroblock.html#a511c27f29e6b6e905539fda6518d6d2d", null ],
    [ "seg_skip_block", "structmacroblock.html#a279e29c928b7865495dfb116a3bcc54f", null ],
    [ "actual_num_seg1_blocks", "structmacroblock.html#a25f1da53d124bef096fd810a931ebbe7", null ],
    [ "actual_num_seg2_blocks", "structmacroblock.html#ab55de0eba1eebc220f37fa94bf1cf13a", null ],
    [ "cnt_zeromv", "structmacroblock.html#aec74d7a69efa704dfa7b2669e8ae00d7", null ],
    [ "force_zeromv_skip", "structmacroblock.html#ab0acd9f744836c691dfbd612ce909b59", null ],
    [ "prev_segment_id", "structmacroblock.html#a40cd7e1964cc73f0e54e3e429feefbe0", null ],
    [ "sb_enc", "structmacroblock.html#a914187a1e2c4ac2e7bbc63164dcd822e", null ],
    [ "content_state_sb", "structmacroblock.html#a6c723b72e1d1111363753927ac8b53e7", null ],
    [ "pred_mv_sad", "structmacroblock.html#ad36d4b9e8b99944c6d5c312f241b348d", null ],
    [ "best_pred_mv_sad", "structmacroblock.html#a5af7a6d5609fc762b77b82f5a7e5c14b", null ],
    [ "pred_mv0_sad", "structmacroblock.html#a3dfb9d2b763d7184960693890017c703", null ],
    [ "pred_mv1_sad", "structmacroblock.html#a28abfde9e8cc5098b84aa609605cce4e", null ],
    [ "tpl_keep_ref_frame", "structmacroblock.html#af2e92ae69af37f651668a7b31cd26e29", null ],
    [ "warp_sample_info", "structmacroblock.html#a031b3ac15e79ebba99e3e3c86c7a1133", null ],
    [ "picked_ref_frames_mask", "structmacroblock.html#ab9a918c78e2a823a6aa234c32d6b4c48", null ],
    [ "nonrd_prune_ref_frame_search", "structmacroblock.html#a3ff9e34d5b99575864a4278e105ecdd2", null ],
    [ "part_search_info", "structmacroblock.html#a17fb11d3bc68a52d9d0bfbd024237cf6", null ],
    [ "must_find_valid_partition", "structmacroblock.html#aae99f1ac179f073272682dcf6da0e410", null ],
    [ "skip_mode", "structmacroblock.html#a13dbc93111a73a4bf0ac7f4598fe89d9", null ],
    [ "thresh_freq_fact", "structmacroblock.html#a5b8fc24effcd5f082a0fad4efb1b0f7c", null ],
    [ "winner_mode_stats", "structmacroblock.html#a33897e5529b5ae465aef0fd748c9bf1d", null ],
    [ "winner_mode_count", "structmacroblock.html#aebb266e0d877a120976d2933b297ebee", null ],
    [ "rd_model", "structmacroblock.html#aec77ad10388c3c6d4c2c6c2cc5f68e97", null ],
    [ "inter_modes_info", "structmacroblock.html#adf2150137ef87e1a400bf29b3d0556b6", null ],
    [ "compound_idx", "structmacroblock.html#a51dab6ebd0f86d088d772101895bc207", null ],
    [ "comp_rd_stats", "structmacroblock.html#a93a3d8ca33457be296259242776453cd", null ],
    [ "comp_rd_stats_idx", "structmacroblock.html#a3e33844a3bb8cb9c20dbf3b1f03005c9", null ],
    [ "recalc_luma_mc_data", "structmacroblock.html#a850c0783f1fc99a8e1c74e6dcf9be7ae", null ],
    [ "intrabc_hash_info", "structmacroblock.html#ad64d6927d6567fa6a6c29f2e8fb444af", null ],
    [ "use_mb_mode_cache", "structmacroblock.html#a9fddc59fbcf0e867e336a8d51b54a984", null ],
    [ "mb_mode_cache", "structmacroblock.html#a6124c3e97a13d6823ff16d5d044b8ddf", null ],
    [ "pixel_gradient_info", "structmacroblock.html#a4bd7c7bad1d4df3e10039f4c5e6a8b7e", null ],
    [ "is_sb_gradient_cached", "structmacroblock.html#a8740e0b4847a0367ce2a42d9715bb4aa", null ],
    [ "max_mv_context", "structmacroblock.html#a4cecb2383140b5ce465a3ddcfb774a32", null ],
    [ "mv_limits", "structmacroblock.html#a16078d24dc96053b119488652280e9d0", null ],
    [ "search_site_cfg_buf", "structmacroblock.html#a0f49ca1e5acf1b97155d9d8bf357d4cc", null ],
    [ "txfm_search_params", "structmacroblock.html#aedba3047d9e9acf711eba686fa0e121f", null ],
    [ "txfm_search_info", "structmacroblock.html#ac8455bcc2b83854f86be71bf5f1a3137", null ],
    [ "color_sensitivity_sb", "structmacroblock.html#a322458f98de370f8d8f0c86c39f603f8", null ],
    [ "color_sensitivity_sb_g", "structmacroblock.html#a03b1485aab2e083a9c46970a1886a69f", null ],
    [ "color_sensitivity", "structmacroblock.html#aacddc7a61db595038479414a3139e19b", null ],
    [ "source_variance", "structmacroblock.html#a2768397e93e4a74a5bb41380262a937f", null ],
    [ "pred_sse", "structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0", null ],
    [ "try_merge_partition", "structmacroblock.html#a41dd07e2cc09c9aefdb24018f610a20e", null ],
    [ "src_var_info_of_4x4_sub_blocks", "structmacroblock.html#ad456641e8b4e392bf16b91d7277a2936", null ],
    [ "last_set_offsets_loc", "structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed", null ]
];

==> aom-docs-3.13.1-1-x86_64.pkg.tar.zst: usr/share/doc/aom/structmacroblock.js <==
var structmacroblock =
[
    [ "plane", "structmacroblock.html#a764c3f23fd2e1d581a1265bad933c196", null ],
    [ "e_mbd", "structmacroblock.html#a22c8a3380f06cf7061181e1ba5de5d5a", null ],
    [ "mbmi_ext", "structmacroblock.html#af9333e247364df6c3e316bf5ad221b56", null ],
    [ "mbmi_ext_frame", "structmacroblock.html#a045f36d0d8a27dcd8be792f5cdcdd3b0", null ],
    [ "row_ctx", "structmacroblock.html#a2a5f8b9affa29e2e6f02d438cff7389d", null ],
    [ "tile_pb_ctx", "structmacroblock.html#adbcb7d6e4e0fbe5180f62dd9d2d9d8a3", null ],
    [ "cb_coef_buff", "structmacroblock.html#aac7182bb34bf1ca7c57b5ca0acdf085f", null ],
    [ "cb_offset", "structmacroblock.html#ae1c34d0f490e6fde5878029e6446664e", null ],
    [ "obmc_buffer", "structmacroblock.html#a90eeb3bb2b16490acc010bff8cd69f4a", null ],
    [ "palette_buffer", "structmacroblock.html#a646112bcb60cf889bdfefc2c213086ec", null ],
    [ "comp_rd_buffer", "structmacroblock.html#a5616dd030329ca191ce1a31200459473", null ],
    [ "tmp_conv_dst", "structmacroblock.html#a37f1df249ef1e12f57b9bfa2786aa086", null ],
    [ "tmp_pred_bufs", "structmacroblock.html#a099a8be27fac5a66f655471c91eb2d93", null ],
    [ "qindex", "structmacroblock.html#aada35cc4d590ca2912c3305d49d1e460", null ],
    [ "delta_qindex", "structmacroblock.html#a00c8c8d03fa0236917ca3e6485f5f0c5", null ],
    [ "rdmult_delta_qindex", "structmacroblock.html#ae221073ae8aa1096368b0685b0397830", null ],
    [ "rdmult_cur_qindex", "structmacroblock.html#a1104922bd603db4353f9e91d5c2a6fcd", null ],
    [ "rdmult", "structmacroblock.html#a1bfbaf644bed64fcdc41119e2da0843f", null ],
    [ "intra_sb_rdmult_modifier", "structmacroblock.html#a54fe4d282d137868d98adc7ad7abb9dd", null ],
    [ "rb", "structmacroblock.html#a228e767c53ab8ab4d8bfe446d33de98e", null ],
    [ "mb_energy", "structmacroblock.html#a0de89964c4b6f0c74b9a74c494a8f6e4", null ],
    [ "sb_energy_level", "structmacroblock.html#a07e39b2368528999366be1ea379f50e0", null ],
    [ "mode_costs", "structmacroblock.html#a3c8ed6c74a25055e311a476b5ad4702c", null ],
    [ "mv_costs", "structmacroblock.html#abe2b85272a08056fb6332699d350fe98", null ],
    [ "dv_costs", "structmacroblock.html#a5c84d87000da6a479c483aceee12f346", null ],
    [ "coeff_costs", "structmacroblock.html#a165159d92c9f6d7c4ec1b8ad6c47f4f0", null ],
    [ "errorperbit", "structmacroblock.html#adb20ef0cebd61dc8a468f5b928f27a10", null ],
    [ "sadperbit", "structmacroblock.html#a511c27f29e6b6e905539fda6518d6d2d", null ],
    [ "seg_skip_block", "structmacroblock.html#a279e29c928b7865495dfb116a3bcc54f", null ],
    [ "actual_num_seg1_blocks", "structmacroblock.html#a25f1da53d124bef096fd810a931ebbe7", null ],
    [ "actual_num_seg2_blocks", "structmacroblock.html#ab55de0eba1eebc220f37fa94bf1cf13a", null ],
    [ "cnt_zeromv", "structmacroblock.html#aec74d7a69efa704dfa7b2669e8ae00d7", null ],
    [ "force_zeromv_skip_for_sb", "structmacroblock.html#ab8ce5ba8d4e6d824842600222d9682a4", null ],
    [ "force_zeromv_skip_for_blk", "structmacroblock.html#a93decab9361681cbf5017a122ce864af", null ],
    [ "prev_segment_id", "structmacroblock.html#a40cd7e1964cc73f0e54e3e429feefbe0", null ],
    [ "sb_enc", "structmacroblock.html#a914187a1e2c4ac2e7bbc63164dcd822e", null ],
    [ "content_state_sb", "structmacroblock.html#a6c723b72e1d1111363753927ac8b53e7", null ],
    [ "pred_mv_sad", "structmacroblock.html#ad36d4b9e8b99944c6d5c312f241b348d", null ],
    [ "best_pred_mv_sad", "structmacroblock.html#a5af7a6d5609fc762b77b82f5a7e5c14b", null ],
    [ "pred_mv0_sad", "structmacroblock.html#a3dfb9d2b763d7184960693890017c703", null ],
    [ "pred_mv1_sad", "structmacroblock.html#a28abfde9e8cc5098b84aa609605cce4e", null ],
    [ "tpl_keep_ref_frame", "structmacroblock.html#af2e92ae69af37f651668a7b31cd26e29", null ],
    [ "warp_sample_info", "structmacroblock.html#a031b3ac15e79ebba99e3e3c86c7a1133", null ],
    [ "picked_ref_frames_mask", "structmacroblock.html#ab9a918c78e2a823a6aa234c32d6b4c48", null ],
    [ "nonrd_prune_ref_frame_search", "structmacroblock.html#a3ff9e34d5b99575864a4278e105ecdd2", null ],
    [ "part_search_info", "structmacroblock.html#a17fb11d3bc68a52d9d0bfbd024237cf6", null ],
    [ "must_find_valid_partition", "structmacroblock.html#aae99f1ac179f073272682dcf6da0e410", null ],
    [ "skip_mode", "structmacroblock.html#a13dbc93111a73a4bf0ac7f4598fe89d9", null ],
    [ "thresh_freq_fact", "structmacroblock.html#a5b8fc24effcd5f082a0fad4efb1b0f7c", null ],
    [ "winner_mode_stats", "structmacroblock.html#a33897e5529b5ae465aef0fd748c9bf1d", null ],
    [ "winner_mode_count", "structmacroblock.html#aebb266e0d877a120976d2933b297ebee", null ],
    [ "rd_model", "structmacroblock.html#aec77ad10388c3c6d4c2c6c2cc5f68e97", null ],
    [ "inter_modes_info", "structmacroblock.html#adf2150137ef87e1a400bf29b3d0556b6", null ],
    [ "compound_idx", "structmacroblock.html#a51dab6ebd0f86d088d772101895bc207", null ],
    [ "comp_rd_stats", "structmacroblock.html#a93a3d8ca33457be296259242776453cd", null ],
    [ "comp_rd_stats_idx", "structmacroblock.html#a3e33844a3bb8cb9c20dbf3b1f03005c9", null ],
    [ "recalc_luma_mc_data", "structmacroblock.html#a850c0783f1fc99a8e1c74e6dcf9be7ae", null ],
    [ "intrabc_hash_info", "structmacroblock.html#ad64d6927d6567fa6a6c29f2e8fb444af", null ],
    [ "use_mb_mode_cache", "structmacroblock.html#a9fddc59fbcf0e867e336a8d51b54a984", null ],
    [ "mb_mode_cache", "structmacroblock.html#a6124c3e97a13d6823ff16d5d044b8ddf", null ],
    [ "pixel_gradient_info", "structmacroblock.html#a4bd7c7bad1d4df3e10039f4c5e6a8b7e", null ],
    [ "is_sb_gradient_cached", "structmacroblock.html#a8740e0b4847a0367ce2a42d9715bb4aa", null ],
    [ "reuse_inter_pred", "structmacroblock.html#a4848ea120426955d3d5ab28c00256422", null ],
    [ "max_mv_context", "structmacroblock.html#a4cecb2383140b5ce465a3ddcfb774a32", null ],
    [ "mv_limits", "structmacroblock.html#a16078d24dc96053b119488652280e9d0", null ],
    [ "search_site_cfg_buf", "structmacroblock.html#a0f49ca1e5acf1b97155d9d8bf357d4cc", null ],
    [ "txfm_search_params", "structmacroblock.html#aedba3047d9e9acf711eba686fa0e121f", null ],
    [ "txfm_search_info", "structmacroblock.html#ac8455bcc2b83854f86be71bf5f1a3137", null ],
    [ "color_sensitivity_sb", "structmacroblock.html#a685c69af9ba838c27e4511d79bd55602", null ],
    [ "color_sensitivity_sb_g", "structmacroblock.html#aeb89ef22421a3d3ce7ee8d87222cd4ff", null ],
    [ "color_sensitivity_sb_alt", "structmacroblock.html#ab98b279dcf8ab1def1577a55f69eefe9", null ],
    [ "color_sensitivity", "structmacroblock.html#a7c1c40cf6f00bb9d84721d5789f4f22a", null ],
    [ "min_dist_inter_uv", "structmacroblock.html#a0e5ebbd5564bfe2b6db777a6564eed68", null ],
    [ "color_palette_thresh", "structmacroblock.html#a635c6e86190fcb9d6d86704c40928683", null ],
    [ "force_color_check_block_level", "structmacroblock.html#a6c9a64f1c0afcb912cb36a4190e33c36", null ],
    [ "dqcoeff_buf", "structmacroblock.html#a4628bff3ec7fa647b930a0635845dcc5", null ],
    [ "source_variance", "structmacroblock.html#a2768397e93e4a74a5bb41380262a937f", null ],
    [ "block_is_zero_sad", "structmacroblock.html#a147a39e4ed48ab5e0f1a8bbc72165e88", null ],
    [ "sb_me_partition", "structmacroblock.html#ae224deb58c16db949cf65c36897cf273", null ],
    [ "sb_me_block", "structmacroblock.html#a29c39720d5ddc64d38cd49798ff2941a", null ],
    [ "sb_col_scroll", "structmacroblock.html#a22016a323ab1012addfbed36e8b499be", null ],
    [ "sb_row_scroll", "structmacroblock.html#ac5cf42a4e091bddd28ef84c660e86485", null ],
    [ "sb_me_mv", "structmacroblock.html#a8a9879bd67940ef605eeab288e6176c5", null ],
    [ "sb_force_fixed_part", "structmacroblock.html#a1f0affa45f986820db4067b9fe931a3a", null ],
    [ "pred_sse", "structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0", null ],
    [ "try_merge_partition", "structmacroblock.html#a41dd07e2cc09c9aefdb24018f610a20e", null ],
    [ "src_var_info_of_4x4_sub_blocks", "structmacroblock.html#ad456641e8b4e392bf16b91d7277a2936", null ],
    [ "last_set_offsets_loc", "structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed", null ],
    [ "palette_pixels", "structmacroblock.html#adac07c2ba2d02afc50a786074d07cfea", null ],
    [ "sb_stats_cache", "structmacroblock.html#adf69f9def7a56f79122566c3da0d7308", null ],
    [ "sb_fp_stats", "structmacroblock.html#aa60f4777729dcb44b070647577bc5a48", null ]
];
